@@ -17,8 +17,10 @@ from loguru import logger
 
 from wud.aws import s3bucket_json_get
 
-convar_dict = s3bucket_json_get('wud-cloudhouse','maruball_convar.json')
 
+def convar_dict():
+    convar_dict = s3bucket_json_get('wud-cloudhouse','maruball_convar.json')
+    return convar_dict
 
 
 @dataclass
@@ -50,10 +52,16 @@ class MatchPreview(Match):
     latest_matches_away: List[PrevMatch] = None
     
     
+@dataclass
+class Player:
+    name: str = ''
+    team: str = ''
+    goal: int = None
+    assist : int = None
+
 
 def team_name_revise0(team, source_input, source_output):
     
-    
     epl = copy.deepcopy(convar_dict['team_name']['epl'])
     ucl_erp = copy.deepcopy(convar_dict['team_name']['ucl_erp'])
     tpl = copy.deepcopy(convar_dict['team_name']['tpl'])
