@@ -18,7 +18,10 @@ def open_browser(driver_path, url):
     while not loaded:
         try:
 
-            driver = webdriver.Chrome(executable_path=driver_path)
+            chrome_options = webdriver.ChromeOptions()
+            chrome_options.add_argument('disable-notifications')
+            
+            driver = webdriver.Chrome(executable_path=driver_path, options=chrome_options)
             start = datetime.now()
             driver.set_page_load_timeout(60)
             driver.get(url)
